#ifndef NT2_INCLUDE_FUNCTIONS_POLYFIT_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_POLYFIT_HPP_INCLUDED

#include <nt2/polynom/include/functions/polyfit.hpp>

#endif
